# coding: utf-8
# author: Gabriel Couture
import dataclasses
import re
from typing import Pattern


@dataclasses.dataclass
class AllowedStructureName:
    regex: Pattern
    type: str


ALLOWED_STRUCTURE_NAMES = [
    AllowedStructureName(re.compile(r'^(A_Aorta~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Aorta_Asc~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Brachiocephls~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Celiac~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Femoral_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Femoral_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Femoral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Femoral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Humeral_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Humeral_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Humeral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Humeral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Hypophyseal~?_I(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Hypophyseal~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_LAD~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Mesenteric~?_I(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Mesenteric~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Pulmonary~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Acetabulum~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Acetabulum~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Acetabulums~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(AirWay~?_Dist(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(AirWay~?_Prox(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Anus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Appendix~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Atrium~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Atrium~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Atrium~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BileDuct_Common~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bladder~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bladder_Wall~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bladder-CTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Body-PTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ethmoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Frontal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Hyoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ischium~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Ischium~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Mandible~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Mastoid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Mastoid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Occipital~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Sphenoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatic~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatic~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatics~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BoneMarrow~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BoneMarrow_Act~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bowel~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bowel_Large~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bowel_Small~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BrachialPlex~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BrachialPlex~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(BrachialPlexs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brain~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brain-CTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brain-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brain-PTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brainstem~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brainstem_Core~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Brainstem_Surf~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Breast~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Breast~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Breasts~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus_PRVxx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bronchus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Canal_Anal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Carina~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cartlg_Thyroid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CaudaEquina~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cavernosum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cavity_Nasal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cavity_Oral~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cecum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cerebellum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cervix~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Chestwall~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Chestwall~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Chestwall~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cist_Pontine~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cist_Suprasellar~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Clavicle~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Clavicle~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_III~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_III~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_III~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_IX~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_IX~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_IX~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_V~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_V~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_V~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VI~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VI~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VI~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VII~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VII~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VII~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XI~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XI~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XI~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XII~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XII~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CN_XII~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cochlea~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cochlea~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cochlea~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon_Ascending~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon_Decending~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon_PTVxx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon_Sigmoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Colon_Transverse~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cornea~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cornea~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cornea~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(CribriformPlate~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cricoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Cricopharyngeus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Dens~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Diaphragm~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Duodenum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_External~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_External~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Externals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Internal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Internal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Internals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Edema~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Elbow~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Elbow~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Elbow~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Esophagus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_I(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Esophagus_M~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_NAdj(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(External~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Eye~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Eye~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Eyes~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Base~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Base~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Head~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Head~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Joint~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Joint~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Neck~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Neck~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Shaft~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femur_Shaft~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Femurs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Fibula~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Fibula~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Fibula~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Fossa_Jugular~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Fossa_Posterior~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Gallbladder~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Genitals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Adrenal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Adrenal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Parathyroid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Subling~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Subling~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Sublings~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Submand~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Submand~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Submands~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Thymus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glnd_Thyroid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Glottis~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(GreatVes~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(GreatVes~?_NAdj(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(GrowthPlate~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(GrowthPlate~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hardpalate~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Heart~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hemisphere~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hemisphere~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hemispheres~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hippocampi~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hippocampus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hippocampus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Humerus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Humerus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Hypothalmus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ileum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Jejunum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Jejunum_Ileum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_Surface~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilum~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilum~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilums~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_L-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Pelvis~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_Pelvis~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney_R-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidney-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Kidneys~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Knee~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Knee~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Knee~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Laryngl_Pharynx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Larynx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Larynx_SG~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lens~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lens~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lens~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lig_Hepatogastrc~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lips~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Liver~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Liver-CTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Liver-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Central~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Central~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Centrals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L1~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L1~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L2~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L2~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L3~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L3~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Lateral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Lateral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Laterals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectoral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectoral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectorals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscap~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscap~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscaps~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Brachioceph~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Brachioceph~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Brachiocephs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulm~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulm~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulms~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Diaphragmatic~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_IMN~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_IMN~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_IMNs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Intercostals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Ligamentarter~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_lliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Mediastinals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IA~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IA~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IB~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IB~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_II~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_II~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIA~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIA~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIB~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIB~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_III~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_III~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IV~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IV~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_V~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_V~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VA~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VA~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VB~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VB~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VC~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VC~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VI~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VI~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VII~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VII~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Obturator~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Obturator~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Paraaortic~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Paramammary~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Paramammary~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Paramammarys~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Parasternal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Parasternal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Parasternals~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pelvic~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pelvic~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pelvics~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Portahepatis~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Presacral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Presacral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonary~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonary~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonarys~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Sclav~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Sclav~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Supmammary~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Supmammary~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Supmammarys~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_LLL(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_LUL(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_RLL(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_RML(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lung~?_RUL(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lungs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lungs-CTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lungs-GTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lungs-ITV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Lungs-PTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Malleus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Malleus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Malleus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Maxilla~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Maxilla~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Maxilla~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Mediastinum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?_I(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict_M~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Digastric~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Digastric~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Platysma~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Platysma~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Pterygoid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Pterygoid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Sclmast~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Sclmast~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Musc_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nasalconcha_LI~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nasalconcha_RI~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nasopharynx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nose~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nrv_Peripheral~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Nrv_Root~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(OpticChiasm~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Orbit~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Orbit~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Oropharynx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ovaries~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ovary~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ovary~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Palate_Soft~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(PancJejuno~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pancreas~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pancreas_Head~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pancreas_Tail~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Parametrium~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Parotid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Parotid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Parotids~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(PenileBulb~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Penis~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pericardium~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Perineum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Peritoneum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pharynx~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pineal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pituitary~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pons~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Proc_Condyloid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Proc_Condyloid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Proc_Coronoid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Proc_Coronoid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Prostate~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(ProstateBed~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Prosthesis~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Lat~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Lat~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Med~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Med~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Radius~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Radius~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rectal_Wall~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rectum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Retina~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Retina~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Retinas~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib01~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib01~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib02~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib02~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib03~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib03~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib04~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib04~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib05~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib05~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib06~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib06~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib07~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib07~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib08~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib08~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib09~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib09~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib10~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib10~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib11~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib11~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib12~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Rib12~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SacralPlex~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sacrum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scalp~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scapula~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scapula~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scar~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scar_Boost~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Scrotum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?_Dist(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?_Prox(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Ethmoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Skin~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Skin_Perineum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Skin_Peritoneum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Skull~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Bowel_Small~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophar~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophar~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophars~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Supraclav~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spc_Supraclav~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sphincter_Anal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCanal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCord~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Cerv~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Lum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Sac~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Thor~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spleen~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spleen_Hilum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Spongiosum~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Stapes~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Stapes~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Stapes~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Stomach~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Strct_Suprapatel~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Surf_Eye~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(SurgicalBed~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Sys_Ventricular~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tendon_Quad~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Testis~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Testis~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Testis~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(ThecalSac~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Thoracic_Duct~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_All~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Tonsil~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Trachea~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Trachea~?_NAdj(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ureter~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ureter~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(UreterDivert~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ureters~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Urethra~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Urethra_Prostatc~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Uterus~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Azygos~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Brachioceph~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Brachioceph~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Jugular~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Int~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Int~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Portal~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Pulmonary~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Subclavian~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Subclavian~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Subclavians~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Venacava~?_I(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(V_Venacava~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Vagina~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Vagina_Surf~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VaginalCuff~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Valve~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Valve_Aortic~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Valve_Mitral~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Valve_Pulmonic~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Valve_Tricuspid~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C1~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C2~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C3~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C4~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C5~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C6~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_C7~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_L1~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_L2~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_L3~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_L4~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_L5~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB~?_S(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_S1~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_S2~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_S3~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_S4~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_S5~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T01~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T02~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T03~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T04~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T05~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T06~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T07~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T08~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T09~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T10~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T11~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VB_T12~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VBs~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ventricle~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ventricle~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Ventricle~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VocalCord~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VocalCord~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(VocalCords~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Vomer~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Vulva~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Wall_Vagina~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Thalami~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Thalamus~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Thalamus~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Third_Ventricle~?(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(InternCapsule~?_L(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(InternCapsule~?_R(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Pharynx-PTV(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^Body$'), 'EXTERNAL'),
    AllowedStructureName(re.compile(r'^(A_Aorta~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Aorta_Asc~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Brachiocephls~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Carotid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Celiac~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Coronary~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Femoral_Cflx~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Femoral_Cflx~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Femoral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Femoral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Humeral_Cflx~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Humeral_Cflx~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Humeral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Humeral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Hypophyseal~?_PRV\d{0,2}_I(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Hypophyseal~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Cflx~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Cflx~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Ext~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Ext~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Int~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac_Int~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Iliac~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_LAD~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Mesenteric~?_PRV\d{0,2}_I(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Mesenteric~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Pulmonary~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Subclavian~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(A_Vertebral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Acetabulum~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Acetabulum~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Acetabulums~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(AirWay~?_PRV\d{0,2}_Dist(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(AirWay~?_PRV\d{0,2}_Prox(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Anus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Appendix~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Arytenoid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Atrium~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Atrium~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Atrium~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BileDuct_Common~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bladder~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bladder_Wall~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bladder-CTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Body-PTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ethmoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Frontal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Hyoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ilium~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Incus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ischium~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Ischium~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Lacrimal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Mandible~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Mastoid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Mastoid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Nasal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Occipital~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Palatine~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Parietal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Pelvic~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Sphenoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Temporal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatic~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatic~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bone_Zygomatics~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BoneMarrow~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BoneMarrow_Act~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bowel~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bowel_Large~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bowel_Small~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BrachialPlex~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BrachialPlex~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(BrachialPlexs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brain~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brain-CTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brain-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brain-PTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brainstem~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brainstem_Core~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Brainstem_Surf~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Breast~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Breast~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Breasts~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus_Main~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus_PRVxx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bronchus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Canal_Anal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Carina~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cartlg_Thyroid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CaudaEquina~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cavernosum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cavity_Nasal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cavity_Oral~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cecum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cerebellum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cerebrum~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cervix~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Chestwall~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Chestwall~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Chestwall~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cist_Pontine~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cist_Suprasellar~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Clavicle~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Clavicle~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_III~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_III~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_III~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_IX~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_IX~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_IX~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_V~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_V~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_V~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VI~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VI~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VI~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VII~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VII~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VII~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_VIII~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XI~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XI~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XI~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XII~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XII~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CN_XII~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cochlea~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cochlea~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cochlea~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon_Ascending~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon_Decending~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon_PTVxx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon_Sigmoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Colon_Transverse~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cornea~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cornea~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cornea~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(CribriformPlate~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cricoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Cricopharyngeus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Dens~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Diaphragm~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Duodenum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_External~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_External~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Externals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Internal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Internal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Internals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ear_Middle~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Edema~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Elbow~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Elbow~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Elbow~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_PRV\d{0,2}_I(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Esophagus_M~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_PRV\d{0,2}_NAdj(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Esophagus~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(External~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Eye~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Eye~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Eyes~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Base~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Base~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Head~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Head~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Joint~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Joint~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Neck~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Neck~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Shaft~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femur_Shaft~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Femurs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Fibula~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Fibula~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Fibula~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Fossa_Jugular~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Fossa_Posterior~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Gallbladder~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Genitals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Adrenal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Adrenal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Lacrimal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Parathyroid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Subling~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Subling~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Sublings~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Submand~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Submand~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Submands~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Thymus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glnd_Thyroid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Glottis~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(GreatVes~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(GreatVes~?_PRV\d{0,2}_NAdj(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(GrowthPlate~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(GrowthPlate~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hardpalate~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Heart~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hemisphere~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hemisphere~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hemispheres~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hippocampi~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hippocampus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hippocampus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Humerus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Humerus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Hypothalmus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ileum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Jejunum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Jejunum_Ileum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Elbow~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Glenohum~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_Surface~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Joint_TM~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Cortex~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilum~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilum~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Hilums~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_L-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Pelvis~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_Pelvis~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney_R-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidney-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Kidneys~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Knee~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Knee~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Knee~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Laryngl_Pharynx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Larynx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Larynx_SG~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lens~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lens~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lens~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lig_Hepatogastrc~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lips~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Liver~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Liver-CTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Liver-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Apical~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Central~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Central~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Centrals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L1~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L1~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L2~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L2~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L3~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_L3~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Lateral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Lateral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Laterals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectoral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectoral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Pectorals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscap~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscap~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ax_Subscaps~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Brachioceph~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Brachioceph~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Brachiocephs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulm~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulm~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Bronchpulms~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Diaphragmatic~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Ext~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Ext~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Iliac_Int~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Iliac~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Iliac~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_IMN~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_IMN~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_IMNs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Inguinofem~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Intercostals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Ligamentarter~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_lliac_Int~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Mediastinals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IA~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IA~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IB~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IB~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_II~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_II~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIA~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIA~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIB~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IIB~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_III~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_III~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IV~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_IV~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_V~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_V~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VA~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VA~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VB~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VB~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VC~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VC~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VI~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VI~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VII~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Neck_VII~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Obturator~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Obturator~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Paraaortic~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Paramammary~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Paramammary~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Paramammarys~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Parasternal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Parasternal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Parasternals~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pelvic~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pelvic~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pelvics~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Portahepatis~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Presacral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Presacral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonary~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonary~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Pulmonarys~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Sclav~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Sclav~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Supmammary~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Supmammary~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Supmammarys~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(LN_Trachbrnchs~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Frontal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Occipital~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Parietal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lobe_Temporal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_LLL(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_LUL(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_RLL(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_RML(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lung~?_PRV\d{0,2}_RUL(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lungs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lungs-CTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lungs-GTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lungs-ITV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Lungs-PTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Malleus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Malleus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Malleus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Maxilla~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Maxilla~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Maxilla~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Mediastinum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?_PRV\d{0,2}_I(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict_M~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Constrict~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Digastric~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Digastric~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Masseter~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Platysma~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Platysma~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Pterygoid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Pterygoid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Sclmast~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Sclmast~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Temporal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Musc_Temporal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nasalconcha_LI~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nasalconcha_RI~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nasopharynx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nose~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nrv_Peripheral~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Nrv_Root~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(OpticChiasm~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(OpticNrv~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Orbit~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Orbit~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Oropharynx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ovaries~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ovary~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ovary~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Palate_Soft~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(PancJejuno~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pancreas~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pancreas_Head~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pancreas_Tail~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Parametrium~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Parotid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Parotid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Parotids~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(PenileBulb~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Penis~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pericardium~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Perineum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Peritoneum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pharynx~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pineal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pituitary~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pons~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Proc_Condyloid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Proc_Condyloid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Proc_Coronoid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Proc_Coronoid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Prostate~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(ProstateBed~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Prosthesis~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Lat~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Lat~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Med~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pterygoid_Med~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(PubicSymphys~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Radius~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Radius~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rectal_Wall~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rectum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Retina~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Retina~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Retinas~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib01~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib01~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib02~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib02~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib03~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib03~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib04~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib04~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib05~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib05~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib06~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib06~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib07~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib07~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib08~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib08~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib09~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib09~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib10~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib10~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib11~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib11~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib12~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Rib12~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SacralPlex~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sacrum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scalp~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scapula~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scapula~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scar~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scar_Boost~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Scrotum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?_PRV\d{0,2}_Dist(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SeminalVes~?_PRV\d{0,2}_Prox(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Ethmoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Frontal~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Maxilry~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sinus_Sphenoid~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Skin~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Skin_Perineum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Skin_Peritoneum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Skull~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Bowel_Small~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophar~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophar~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrophars~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Retrosty~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Supraclav~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spc_Supraclav~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sphincter_Anal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCanal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCord~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Cerv~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Lum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Sac~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SpinalCord_Thor~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spleen~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spleen_Hilum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Spongiosum~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Stapes~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Stapes~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Stapes~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Stomach~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Strct_Suprapatel~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Surf_Eye~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(SurgicalBed~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Sys_Ventricular~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tendon_Quad~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Testis~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Testis~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Testis~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(ThecalSac~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Thoracic_Duct~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_All~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Base~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tongue_Oral~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Tonsil~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Trachea~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Trachea~?_PRV\d{0,2}_NAdj(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ureter~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ureter~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(UreterDivert~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ureters~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Urethra~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Urethra_Prostatc~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Uterus~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Azygos~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Brachioceph~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Brachioceph~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Ext~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Ext~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Int~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac_Int~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Iliac~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Jugular~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Ext~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Ext~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Int~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Jugular_Int~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Portal~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Pulmonary~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Subclavian~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Subclavian~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Subclavians~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Venacava~?_PRV\d{0,2}_I(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(V_Venacava~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Vagina~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Vagina_Surf~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VaginalCuff~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Valve~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Valve_Aortic~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Valve_Mitral~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Valve_Pulmonic~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Valve_Tricuspid~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C1~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C2~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C3~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C4~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C5~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C6~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_C7~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_L1~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_L2~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_L3~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_L4~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_L5~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB~?_PRV\d{0,2}_S(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_S1~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_S2~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_S3~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_S4~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_S5~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T01~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T02~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T03~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T04~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T05~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T06~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T07~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T08~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T09~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T10~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T11~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VB_T12~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VBs~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ventricle~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ventricle~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Ventricle~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VocalCord~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VocalCord~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(VocalCords~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Vomer~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Vulva~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Wall_Vagina~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Thalami~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Thalamus~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Thalamus~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Third_Ventricle~?_PRV\d{0,2}(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(InternCapsule~?_PRV\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(InternCapsule~?_PRV\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Pharynx-PTV(\^[\w\d_\+-]+)?)$'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^(Bolus(_\d{2}mm)?(\^[\w\d_\+-]+)?)$'), 'BOLUS'),
    AllowedStructureName(re.compile(r'^(Bag_Bowel(\^[\w\d_\+-]+)?)$'), 'ORGAN'),
    AllowedStructureName(re.compile(r'^(Bag_Ostomy(\^[\w\d_\+-]+)?)$'), 'NONE'),
    AllowedStructureName(re.compile(r'^(Pacemaker(\^[\w\d_\+-]+)?)$'), 'NONE'),
    AllowedStructureName(re.compile(r'^(Leads(\^[\w\d_\+-]+)?)$'), 'NONE'),
    AllowedStructureName(re.compile(r'^(IDL_\d{4}(\^[\w\d_\+-]+)?)$'), 'DOSE_REGION'),
    AllowedStructureName(re.compile(r'^(IDL_\d{1,2}(\.\d{1,2}Gy)?(\^[\w\d_\+-]+)?)$'), 'DOSE_REGION'),
    AllowedStructureName(re.compile(r'^(I?GTV(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'GTV'),
    AllowedStructureName(re.compile(r'^(I?CTV(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'CTV'),
    AllowedStructureName(re.compile(r'^(PTV!?(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'PTV'),
    AllowedStructureName(re.compile(r'^_'), 'NONE'),
    AllowedStructureName(re.compile(r'^_'), 'AVOIDANCE'),
    AllowedStructureName(re.compile(r'^_'), 'CONTROL'),
    AllowedStructureName(re.compile(r'^_Contrast'), 'CONTRAST_AGENT'),
    AllowedStructureName(re.compile(r'^Encompass( Base)?$'), 'SUPPORT'),
    AllowedStructureName(re.compile(r'^_Mask'), 'SUPPORT'),
]
